/* this file is processed by gcc with special options to extract
   a list of errno codes.  */
#include <errno.h>

/*
  Local Variables:
  c-file-style: "gnu"
  End:
*/
